@@ -115,8 +115,6 @@ class Sale:
             for key, value in values.iteritems():
                 if '.' not in key:
                     new_values[key] = value
-                if key == 'taxes' and value:
-                    new_values[key] = [('set', value)]
             SaleLine.write([order_line], new_values)
             return order_line
         else:
@@ -126,6 +124,7 @@ class Sale:
                 '_parent_sale.party': self.party.id,
                 'sale': self.id,
                 'type': 'line',
+                'sequence': 10,
                 'quantity': quantity,
                 'unit': None,
                 'description': None,
@@ -139,7 +138,7 @@ class Sale:
                 if '.' not in key:
                     new_values[key] = value
                 if key == 'taxes' and value:
-                    new_values[key] = [('set', value)]
+                    new_values[key] = [('add', value)]
             return SaleLine.create([new_values])[0]
 
 
@@ -148,10 +147,7 @@ class SaleLine:
 
     def refresh_taxes(self):
         "Refresh taxes of sale line"
-        SaleLine = Pool().get('sale.line')
-
         values = self.on_change_product()
         if 'taxes' in values:
-            SaleLine.write([self], {
-                'taxes': [('set', values['taxes'])]
-            })
+            self.taxes = values['taxes']
+            self.save()
